@@ -144,6 +144,20 @@ static GONamedColor const default_color_set [] = {
 
 	{ 0, NULL},
 };
+
+gboolean
+go_color_palette_query (int n, GONamedColor *color)
+{
+	if (n < 0 || n >= (int)G_N_ELEMENTS (default_color_set) - 1)
+		return FALSE;
+
+	color->name = _(default_color_set[n].name);
+	color->color = default_color_set[n].color;
+	return TRUE;
+}
+
+
+
 const GONamedColor *
 _go_color_palette_default_color_set (void)
 {
@@ -461,9 +475,9 @@ go_color_palette_set_group (GOColorPalette *p, GOColorGroup *cg)
 
 static GtkWidget *
 go_color_palette_setup (GOColorPalette *pal,
-		     char const *no_color_label,
-		     int cols, int rows,
-		     GONamedColor const *color_names)
+			char const *no_color_label,
+			int cols, int rows,
+			GONamedColor const *color_names)
 {
 	GtkWidget	*w, *grid;
 	int pos, row, col = 0;
